@@ -20,7 +20,6 @@
 #include "gl-application.h"
 
 #include <glib/gi18n.h>
-#include <libadwaita-1/adwaita.h>
 
 #include "gl-categorylist.h"
 #include "gl-eventtoolbar.h"
@@ -33,7 +32,7 @@
 struct _GlApplication
 {
     /*< private >*/
-    GtkApplication parent_instance;
+    AdwApplication parent_instance;
 };
 
 typedef struct
@@ -44,7 +43,7 @@ typedef struct
     gchar *monospace_font;
 } GlApplicationPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GlApplication, gl_application, GTK_TYPE_APPLICATION)
+G_DEFINE_TYPE_WITH_PRIVATE (GlApplication, gl_application, ADW_TYPE_APPLICATION)
 
 static const gchar DESKTOP_SCHEMA[] = "org.gnome.desktop.interface";
 static const gchar SETTINGS_SCHEMA[] = "org.gnome.Logs";
@@ -68,19 +67,45 @@ on_new_window (GSimpleAction *action,
     gtk_window_present (GTK_WINDOW (window));
 }
 
+static void
+on_help_launch_cb (GtkUriLauncher *launcher,
+                   GAsyncResult *res,
+                   gpointer user_data)
+{
+  GtkWidget *error_dialog;
+  GtkWindow *active_window = GTK_WINDOW (user_data);
+  g_autoptr (GError) error = NULL;
+
+  if (!gtk_uri_launcher_launch_finish (launcher, res, &error))
+  {
+    error_dialog = adw_message_dialog_new (active_window,
+                                           _("Failed To Open Help"),
+                                           NULL);
+    adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (error_dialog),
+                                    _("Failed to open the given help URI: %s"),
+                                    error->message);
+    adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (error_dialog),
+                                     "close", _("_Close"));
+    adw_message_dialog_choose (ADW_MESSAGE_DIALOG (error_dialog),
+                               NULL, NULL, NULL);
+  }
+}
+
 static void
 on_help (GSimpleAction *action,
          GVariant *parameter,
          gpointer user_data)
 {
-    GtkApplication *application;
-    GtkWindow *parent;
+    GtkUriLauncher *launcher;
+    GtkApplication *self = GTK_APPLICATION (user_data);
+    GtkWindow *active_window = gtk_application_get_active_window (self);
 
-    application = GTK_APPLICATION (user_data);
-    parent = gtk_application_get_active_window (application);
-
-    gtk_show_uri (parent, "help:gnome-logs",
-                  GDK_CURRENT_TIME);
+    launcher = gtk_uri_launcher_new ("help:gnome-logs");
+    gtk_uri_launcher_launch (launcher,
+                             active_window,
+                             NULL,
+                             (GAsyncReadyCallback) on_help_launch_cb,
+                             NULL);
 }
 
 static void
@@ -193,16 +218,9 @@ gl_application_startup (GApplication *application)
     /* Calls gtk_init() with no arguments. */
     G_APPLICATION_CLASS (gl_application_parent_class)->startup (application);
 
-    /* Initialize libadwaita widgets and styling */
-    adw_init ();
-
     /* gtk_init() calls setlocale(), so gettext must be called after that. */
     g_set_application_name (_(PACKAGE_NAME));
     gtk_window_set_default_icon_name (PACKAGE_TARNAME);
-
-    /* Opt-in to color scheme user preference. */
-    adw_style_manager_set_color_scheme (adw_style_manager_get_default (),
-                                        ADW_COLOR_SCHEME_PREFER_LIGHT);
 }
 
 static void
@@ -215,7 +233,6 @@ launch_window (GApplication *application)
     const gchar * const export_accel[] = { "<Primary>e", NULL };
     const gchar * const help_accel[] = { "F1", NULL };
     const gchar * const new_window_accel[] = { "<Primary>n", NULL };
-    const gchar * const help_overlay_accel[] = { "<Primary>question", NULL };
 
     priv = gl_application_get_instance_private (GL_APPLICATION (application));
 
@@ -232,9 +249,6 @@ launch_window (GApplication *application)
                                            "app.help", help_accel);
     gtk_application_set_accels_for_action (GTK_APPLICATION (application),
                                            "app.new-window", new_window_accel);
-    gtk_application_set_accels_for_action (GTK_APPLICATION (application),
-                                           "win.show-help-overlay",
-                                           help_overlay_accel);
 
     on_monospace_font_name_changed (priv->desktop, DESKTOP_MONOSPACE_FONT_NAME,
                                     priv);
