@@ -37,9 +37,10 @@ typedef struct
     GtkWidget *event_toolbar;
     GtkWidget *event_list;
     GtkWidget *info_bar;
+    GtkLabel *message_label;
 } GlWindowPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GlWindow, gl_window, HDY_TYPE_APPLICATION_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (GlWindow, gl_window, ADW_TYPE_APPLICATION_WINDOW)
 
 static const gchar SETTINGS_SCHEMA[] = "org.gnome.Logs";
 static const gchar IGNORE_WARNING[] = "ignore-warning";
@@ -96,98 +97,107 @@ on_search (GSimpleAction *action,
     g_simple_action_set_state (action, variant);
 }
 
+static void
+on_save_finish (GObject      *source_object,
+                GAsyncResult *res,
+                gpointer      user_data)
+{
+    GlWindowPrivate *priv;
+    GlEventViewList *event_list;
+    GtkFileDialog *dialog;
+    gboolean have_error = FALSE;
+    gchar *file_content;
+    GFile *output_file;
+    GFileOutputStream *file_ostream;
+    GError *error = NULL;
+    GtkWidget *error_dialog;
+
+    priv = gl_window_get_instance_private (GL_WINDOW (user_data));
+    event_list = GL_EVENT_VIEW_LIST (priv->event_list);
+    dialog = GTK_FILE_DIALOG (source_object);
+
+    output_file = gtk_file_dialog_save_finish (dialog, res, &error);
+
+    if (error != NULL)
+    {
+        g_warning ("Error while replacing exported log messages file: %s",
+                   error->message);
+
+        g_clear_error (&error);
+        return;
+    }
+
+    file_content = gl_event_view_list_get_output_logs (event_list);
+    file_ostream = g_file_replace (output_file, NULL, TRUE,
+                                   G_FILE_CREATE_NONE, NULL, &error);
+    if (error != NULL)
+    {
+        have_error = TRUE;
+
+        g_warning ("Error while replacing exported log messages file: %s",
+                   error->message);
+        g_clear_error (&error);
+    }
+
+    /* Check against NULL pointer to avoid a crash when exporting and there
+     * are no log entries. */
+    if (file_content != NULL)
+    {
+        g_output_stream_write (G_OUTPUT_STREAM (file_ostream), file_content,
+                               strlen (file_content), NULL, &error);
+    }
+
+    if (error != NULL)
+    {
+        have_error = TRUE;
+
+        g_warning ("Error while replacing exported log messages file: %s",
+                   error->message);
+        g_clear_error (&error);
+    }
+
+    g_output_stream_close (G_OUTPUT_STREAM (file_ostream), NULL, &error);
+    if (error != NULL)
+    {
+        have_error = TRUE;
+
+        g_warning ("Error while replacing exported log messages file: %s",
+                   error->message);
+        g_clear_error (&error);
+    }
+
+    if (have_error == TRUE)
+    {
+        error_dialog = adw_message_dialog_new (GTK_WINDOW (user_data),
+                                               _("Export Failed"),
+                                               _("Unable to export log messages to a file"));
+        adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (error_dialog),
+                                         "close", _("_Close"));
+        adw_message_dialog_choose (ADW_MESSAGE_DIALOG (error_dialog),
+                                   NULL, NULL, NULL);
+    }
+
+    g_free (file_content);
+    g_object_unref (file_ostream);
+    g_object_unref (output_file);
+}
+
 static void
 on_export (GSimpleAction *action,
            GVariant *variant,
            gpointer user_data)
 {
-    GlWindowPrivate *priv;
-    GlEventViewList *event_list;
-    GtkFileChooser *file_chooser;
-    GtkFileChooserNative *dialog;
-    gint res;
+    GtkFileDialog *dialog;
 
-    priv = gl_window_get_instance_private (GL_WINDOW (user_data));
-    event_list = GL_EVENT_VIEW_LIST (priv->event_list);
+    dialog = gtk_file_dialog_new ();
 
-    dialog = gtk_file_chooser_native_new (_("Save logs"),
-                                          GTK_WINDOW (user_data),
-                                          GTK_FILE_CHOOSER_ACTION_SAVE,
-                                          _("_Save"),
-                                          _("_Cancel"));
+    gtk_file_dialog_set_initial_name (dialog, _("log messages"));
 
-    file_chooser = GTK_FILE_CHOOSER (dialog);
-    gtk_file_chooser_set_do_overwrite_confirmation (file_chooser, TRUE);
-    gtk_file_chooser_set_current_name (file_chooser, _("log messages"));
-
-    res = gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog));
-    if (res == GTK_RESPONSE_ACCEPT)
-    {
-        gboolean have_error = FALSE;
-        gchar *file_content;
-        GFile *output_file;
-        GFileOutputStream *file_ostream;
-        GError *error = NULL;
-        GtkWidget *error_dialog;
-
-        file_content = gl_event_view_list_get_output_logs (event_list);
-        output_file = gtk_file_chooser_get_file (file_chooser);
-        file_ostream = g_file_replace (output_file, NULL, TRUE,
-                                       G_FILE_CREATE_NONE, NULL, &error);
-        if (error != NULL)
-        {
-            have_error = TRUE;
-
-            g_warning ("Error while replacing exported log messages file: %s",
-                       error->message);
-            g_clear_error (&error);
-        }
-
-        /* Check against NULL pointer to avoid a crash when exporting and there
-         * are no log entries. */
-        if (file_content != NULL)
-        {
-            g_output_stream_write (G_OUTPUT_STREAM (file_ostream), file_content,
-                                   strlen (file_content), NULL, &error);
-        }
-
-        if (error != NULL)
-        {
-            have_error = TRUE;
-
-            g_warning ("Error while replacing exported log messages file: %s",
-                       error->message);
-            g_clear_error (&error);
-        }
-
-        g_output_stream_close (G_OUTPUT_STREAM (file_ostream), NULL, &error);
-        if (error != NULL)
-        {
-            have_error = TRUE;
-
-            g_warning ("Error while replacing exported log messages file: %s",
-                       error->message);
-            g_clear_error (&error);
-        }
-
-        if (have_error == TRUE)
-        {
-            error_dialog = gtk_message_dialog_new (GTK_WINDOW (user_data),
-                                                   GTK_DIALOG_MODAL,
-                                                   GTK_MESSAGE_ERROR,
-                                                   GTK_BUTTONS_CLOSE,
-                                                   "%s",
-                                                   _("Unable to export log messages to a file"));
-            gtk_dialog_run (GTK_DIALOG (error_dialog));
-            gtk_widget_destroy (error_dialog);
-        }
-
-        g_free (file_content);
-        g_object_unref (file_ostream);
-        g_object_unref (output_file);
-    }
-
-    g_object_unref (dialog);
+    gtk_file_dialog_save (dialog,
+                          GTK_WINDOW (user_data),
+                          NULL,
+                          on_save_finish,
+                          user_data);
 }
 
 static void
@@ -255,49 +265,35 @@ on_category_list_changed (GlCategoryList *list,
     g_free (current_boot);
 }
 
-static gboolean
-on_gl_window_key_press_event (GlWindow *window,
-                              GdkEvent *event,
-                              gpointer user_data)
-{
-    GlWindowPrivate *priv;
-    GlEventViewList *event_list;
-    GAction *action;
-
-    priv = gl_window_get_instance_private (window);
-    action = g_action_map_lookup_action (G_ACTION_MAP (window), "search");
-    event_list = GL_EVENT_VIEW_LIST (priv->event_list);
-
-    if (gl_event_view_list_handle_search_event (event_list, action, event) == GDK_EVENT_STOP)
-    {
-        return GDK_EVENT_STOP;
-    }
-
-    return GDK_EVENT_PROPAGATE;
-}
-
 static void
 on_help_button_clicked (GlWindow *window,
                         gint response_id,
                         gpointer user_data)
 {
     GlWindowPrivate *priv;
-    GtkWindow *parent;
-    GError *error = NULL;
+    GtkWidget *error_dialog;
+    g_autoptr (GError) error = NULL;
 
-    parent = GTK_WINDOW (window);
     priv = gl_window_get_instance_private (GL_WINDOW (window));
 
-    gtk_show_uri_on_window (parent, "help:gnome-logs/permissions",
-                            GDK_CURRENT_TIME, &error);
+    g_app_info_launch_default_for_uri ("help:gnome-logs/permissions",
+                                       NULL, &error);
 
-    if (error)
+    if (error != NULL)
     {
-        g_debug ("Error while opening help: %s", error->message);
-        g_error_free (error);
+      error_dialog = adw_message_dialog_new (GTK_WINDOW (window),
+                                             _("Failed To Open Help"),
+                                             NULL);
+      adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (error_dialog),
+                                      _("Failed to open the given help URI: %s"),
+                                      error->message);
+      adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (error_dialog),
+                                       "close", _("_Close"));
+      adw_message_dialog_choose (ADW_MESSAGE_DIALOG (error_dialog),
+                                 NULL, NULL, NULL);
     }
 
-    gtk_widget_hide (priv->info_bar);
+    gtk_widget_set_visible (priv->info_bar, FALSE);
 }
 
 static void
@@ -313,7 +309,7 @@ on_ignore_button_clicked (GlWindow *window,
     settings = g_settings_new (SETTINGS_SCHEMA);
     g_settings_set_boolean (settings, IGNORE_WARNING, TRUE);
 
-    gtk_widget_hide (priv->info_bar);
+    gtk_widget_set_visible (priv->info_bar, FALSE);
 
     g_object_unref (settings);
 }
@@ -354,8 +350,6 @@ gl_window_class_init (GlWindowClass *klass)
     gtk_widget_class_bind_template_child_private (widget_class, GlWindow,
                                                   info_bar);
 
-    gtk_widget_class_bind_template_callback (widget_class,
-                                             on_gl_window_key_press_event);
     gtk_widget_class_bind_template_callback (widget_class,
                                              on_help_button_clicked);
     gtk_widget_class_bind_template_callback (widget_class,
@@ -422,8 +416,7 @@ gl_window_load_journal (GlWindow *window,
 static void
 gl_window_init (GlWindow *window)
 {
-    GtkCssProvider *provider;
-    GdkScreen *screen;
+    GdkDisplay *display;
     GlWindowPrivate *priv;
     GlEventViewList *event_list;
     GtkWidget *categories;
@@ -458,24 +451,11 @@ gl_window_init (GlWindow *window)
     g_signal_connect_swapped (model, "enable_export",
                               G_CALLBACK (enable_export), window);
 
-    provider = gtk_css_provider_new ();
-    g_signal_connect (provider, "parsing-error",
-                      G_CALLBACK (gl_util_on_css_provider_parsing_error),
-                      NULL);
-    gtk_css_provider_load_from_resource (provider,
-                                         "/org/gnome/Logs/gl-style.css");
-
-    screen = gdk_screen_get_default ();
-    gtk_style_context_add_provider_for_screen (screen,
-                                               GTK_STYLE_PROVIDER (provider),
-                                               GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
     settings = g_settings_new (SETTINGS_SCHEMA);
     ignore = g_settings_get_boolean (settings, IGNORE_WARNING);
     /* Don't show info_bar again if users have ever ignored the warning. */
     if (ignore)
     {
-        g_object_unref (provider);
         g_object_unref (settings);
         return;
     }
@@ -488,30 +468,16 @@ gl_window_init (GlWindow *window)
         {
             if (!gl_util_can_read_system_journal (GL_JOURNAL_STORAGE_PERSISTENT))
             {
-                GtkWidget *message_label;
-                GtkWidget *content_area;
+                gtk_label_set_label (priv->message_label, _("Unable to read system logs"));
 
-                message_label = gtk_label_new (_("Unable to read system logs"));
-                gtk_widget_set_hexpand (GTK_WIDGET (message_label), TRUE);
-                gtk_widget_show (message_label);
-                content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (priv->info_bar));
-                gtk_container_add (GTK_CONTAINER (content_area), message_label);
-
-                gtk_widget_show (priv->info_bar);
+                gtk_widget_set_visible (priv->info_bar, TRUE);
             }
 
             if (!gl_util_can_read_user_journal ())
             {
-                GtkWidget *message_label;
-                GtkWidget *content_area;
+                gtk_label_set_label (priv->message_label, _("Unable to read user logs"));
 
-                message_label = gtk_label_new (_("Unable to read user logs"));
-                gtk_widget_set_hexpand (GTK_WIDGET (message_label), TRUE);
-                gtk_widget_show (message_label);
-                content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (priv->info_bar));
-                gtk_container_add (GTK_CONTAINER (content_area), message_label);
-
-                gtk_widget_show (priv->info_bar);
+                gtk_widget_set_visible (priv->info_bar, TRUE);
             }
             break;
         }
@@ -519,38 +485,23 @@ gl_window_init (GlWindow *window)
         {
             if (!gl_util_can_read_system_journal (GL_JOURNAL_STORAGE_VOLATILE))
             {
-                GtkWidget *message_label;
-                GtkWidget *content_area;
+                gtk_label_set_label (priv->message_label, _("Unable to read system logs"));
 
-                message_label = gtk_label_new (_("Unable to read system logs"));
-                gtk_widget_set_hexpand (GTK_WIDGET (message_label), TRUE);
-                gtk_widget_show (message_label);
-                content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (priv->info_bar));
-                gtk_container_add (GTK_CONTAINER (content_area), message_label);
-
-                gtk_widget_show (priv->info_bar);
+                gtk_widget_set_visible (priv->info_bar, TRUE);
             }
             break;
         }
         case GL_JOURNAL_STORAGE_NONE:
         {
-            GtkWidget *message_label;
-            GtkWidget *content_area;
+            gtk_label_set_label (priv->message_label, _("No logs available"));
 
-            message_label = gtk_label_new (_("No logs available"));
-            gtk_widget_set_hexpand (GTK_WIDGET (message_label), TRUE);
-            gtk_widget_show (message_label);
-            content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (priv->info_bar));
-            gtk_container_add (GTK_CONTAINER (content_area), message_label);
-
-            gtk_widget_show (priv->info_bar);
+            gtk_widget_set_visible (priv->info_bar, TRUE);
             break;
         }
         default:
             g_assert_not_reached ();
     }
 
-    g_object_unref (provider);
     g_object_unref (settings);
 }
 
